@@ -290,6 +290,12 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # AI市场公共算法版本Id不存在
 INVALIDPARAMETERVALUE_AIMARKETPUBLICALGOVERSIONNOTEXIST = 'InvalidParameterValue.AIMarketPublicAlgoVersionNotExist'
 
+# 无效的自动重启次数
+INVALIDPARAMETERVALUE_BACKOFFLIMITILLEGAL = 'InvalidParameterValue.BackOffLimitIllegal'
+
+# 该任务不支持自动重启
+INVALIDPARAMETERVALUE_BACKOFFLIMITNOTSUPPORT = 'InvalidParameterValue.BackOffLimitNotSupport'
+
 # 名称不合法。
 INVALIDPARAMETERVALUE_BADNAME = 'InvalidParameterValue.BadName'
 
@@ -338,6 +344,15 @@ INVALIDPARAMETERVALUE_FRAMEWORKVERSIONNOTSUPPORT = 'InvalidParameterValue.Framew
 # 获取CFS的挂载IP失败
 INVALIDPARAMETERVALUE_GETCFSMOUNTIPFAILED = 'InvalidParameterValue.GetCFSMountIPFailed'
 
+# 获取GooseFS实例失败
+INVALIDPARAMETERVALUE_GETGOOSEFSFAILED = 'InvalidParameterValue.GetGooseFSFailed'
+
+# GooseFS的配置不能为空
+INVALIDPARAMETERVALUE_GOOSEFSCONFIGCANNOTEMPTY = 'InvalidParameterValue.GooseFSConfigCannotEmpty'
+
+# 所选的GooseFS实例不存在
+INVALIDPARAMETERVALUE_GOOSEFSNOTEXIST = 'InvalidParameterValue.GooseFSNotExist'
+
 # 训练任务镜像不存在。
 INVALIDPARAMETERVALUE_IMAGENOTFOUND = 'InvalidParameterValue.ImageNotFound'
 
@@ -383,6 +398,9 @@ INVALIDPARAMETERVALUE_TOPICNOTFOUND = 'InvalidParameterValue.TopicNotFound'
 # 裸金属类型资源组不支持配置输入数据
 INVALIDPARAMETERVALUE_UNSUPPORTEDDATACONFIG = 'InvalidParameterValue.UnsupportedDataConfig'
 
+# 不支持使用GooseFS实例
+INVALIDPARAMETERVALUE_UNSUPPORTEDGOOSEFSCONFIG = 'InvalidParameterValue.UnsupportedGooseFSConfig'
+
 # Notebook卷大小只能增加，如需减小容量请重新创建实例。
 INVALIDPARAMETERVALUE_VOLUMESHRINKNOTALLOW = 'InvalidParameterValue.VolumeShrinkNotAllow'
 
